===============
django-page-cms
===============

This Django CMS enables you to create and administrate hierarchical pages in a simple and powerful way.

Django page CMS is based around a placeholders concept. Placeholder is a special template tag that
you use in your page templates. Every time you add a placeholder in your template such field
dynamically appears in the page admin interface.

This CMS is updated to work with Django 1.5

Each page can have a different template with different placeholders.

.. image:: https://github.com/batiste/django-page-cms/raw/master/doc/admin-screenshot1.png

Documentation
=============

For more information about the product:

http://pythonhosted.org/django-page-cms/

